# Generated by Django 3.1.4 on 2021-01-07 21:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0017_auto_20201228_1217'),
        ('api', '0016_auto_20201221_2147'),
    ]

    operations = [
    ]
