# Generated by Django 3.1.3 on 2020-12-08 17:42

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('api', '0008_auto_20201206_2028'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='state',
            field=models.CharField(choices=[('draft', '0'), ('inviting collaborators', '1'), ('open for collaborators', '2'), ('in progress', '3'), ('submitted to event', '4'), ('published', '5'), ('cancelled', '6'), ('done', '7'), ('reopened', '8')], default='draft', max_length=100),
        ),
        migrations.CreateModel(
            name='CollaborationInvite',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message', models.CharField(blank=True, default='', max_length=200)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('rejected', models.DateTimeField(blank=True, null=True)),
                ('from_user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='collab_invite_sent', to=settings.AUTH_USER_MODEL)),
                ('to_project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='collab_invite_of_project', to='api.project')),
                ('to_user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='collab_invite_received', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['created'],
            },
        ),
    ]
