# Generated by Django 3.1.4 on 2020-12-19 11:24

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0014_auto_20201217_1125'),
    ]

    operations = [
        migrations.AlterField(
            model_name='milestone',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='milestones', to='api.project'),
        ),
    ]
