# Generated by Django 3.1.4 on 2021-01-17 10:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0018_merge_20210107_2115'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='remark',
            field=models.CharField(max_length=100),
        ),
    ]
