# Generated by Django 3.1.4 on 2021-01-17 14:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0016_auto_20210117_1657'),
        ('api', '0019_auto_20210117_1056'),
    ]

    operations = [
    ]
