# Generated by Django 3.1.3 on 2020-12-06 20:24

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('api', '0004_merge_20201206_1815'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='members',
            field=models.ManyToManyField(null=True, related_name='members', to=settings.AUTH_USER_MODEL),
        ),
    ]
