# Generated by Django 3.1.4 on 2021-01-17 20:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0020_merge_20210117_1732'),
        ('api', '0020_auto_20210117_1512'),
    ]

    operations = [
    ]
