# Generated by Django 3.1.4 on 2021-01-17 13:57

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('api', '0015_publication'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='publication',
            name='profile',
        ),
        migrations.AddField(
            model_name='publication',
            name='owner',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='publication_owner', to='auth.user'),
            preserve_default=False,
        ),
    ]
