# Generated by Django 3.1.4 on 2020-12-17 11:25

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('api', '0013_merge_20201215_2314'),
    ]

    operations = [
        migrations.AlterField(
            model_name='followrequest',
            name='req_to_user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='follow_requests', to=settings.AUTH_USER_MODEL),
        ),
    ]
