# Generated by Django 3.1.3 on 2020-12-06 14:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0002_collaborationrequest'),
    ]

    operations = [
        migrations.AlterField(
            model_name='collaborationrequest',
            name='to_project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='collab_request_of_project', to='api.project'),
        ),
    ]
