# Generated by Django 3.1.3 on 2020-12-04 14:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='project',
            name='events',
        ),
        migrations.RemoveField(
            model_name='tag',
            name='projects',
        ),
        migrations.AddField(
            model_name='project',
            name='event',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='api.event'),
        ),
        migrations.AddField(
            model_name='project',
            name='tags',
            field=models.ManyToManyField(blank=True, to='api.Tag'),
        ),
    ]
