# Generated by Django 3.1.3 on 2020-12-06 18:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0002_auto_20201204_1708'),
        ('api', '0003_auto_20201206_1712'),
    ]

    operations = [
    ]
