# Generated by Django 3.1.3 on 2020-12-14 17:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0009_auto_20201209_1436'),
        ('api', '0009_auto_20201208_2042'),
    ]

    operations = [
    ]
