# Generated by Django 3.1.5 on 2021-01-24 12:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0022_auto_20210124_1320'),
        ('api', '0022_report'),
    ]

    operations = [
    ]
