# Generated by Django 3.1.3 on 2020-12-15 20:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0010_auto_20201212_1717'),
        ('api', '0012_auto_20201215_1844'),
    ]

    operations = [
    ]
